@@ -10,7 +10,6 @@ import pytest
 from riemann import riemann
 from riemann.riemann import LEFT, MIDDLE, RIGHT
 from riemann.riemann import Dimension
-from riemann.riemann import rsum
 
 F1D = [
     lambda x: 0,
@@ -27,13 +26,37 @@ F2D = [
     lambda x, y: x,
     lambda x, y: y,
     lambda x, y: x + y,
-    lambda x, y: x * y, 
+    lambda x, y: x * y,
     lambda x, y: x ** 2 * y,
     lambda x, y: x * y ** 2,
     lambda x, y: x ** 2 + y ** 2,
     lambda x, y: x ** 2 * y ** 2,
 ]
 
+
+@pytest.mark.parametrize(
+    "func, dimensions", [
+        (lambda x: x, []),
+        (lambda x, y: x + y, []),
+        (lambda x, y: x + y, [Dimension(0, 1, 1, MIDDLE)]),
+        (lambda x, y, z: x + y + z, []),
+        (lambda x, y, z: x + y + z, [Dimension(0, 1, 1, MIDDLE)]),
+        (lambda x, y, z: x + y + z, [Dimension(0, 1, 1, MIDDLE), Dimension(0, 1, 1, MIDDLE)]),
+
+        (lambda: 0, [Dimension(0, 1, 1, MIDDLE)]),
+        (lambda x: x, [Dimension(0, 1, 1, MIDDLE), Dimension(0, 1, 1, MIDDLE)]),
+        (lambda x, y: x + y, [
+            Dimension(0, 1, 1, MIDDLE), Dimension(0, 1, 1, MIDDLE), Dimension(0, 1, 1, MIDDLE)
+        ]),
+    ]
+)
+def test_summation_value_error(func: typing.Callable, dimensions: typing.Iterable[Dimension]):
+    """
+    """
+    with pytest.raises(ValueError):
+        assert riemann.rsum(func, *dimensions)
+
+
 @pytest.mark.parametrize(
     "func, dimensions, x", [
         (F1D[0], [Dimension(0, 1, 1, LEFT)], 0),
